<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Проксі програми</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Необов&apos;язкове</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Позначте пункт «Використовувати проксі» у контекстному меню програми у Launcher після налаштовування</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Некоректний порт</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Відʼєднатися</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ви впевнені, що хочете видалити цю конфігурацію?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Дротове з&apos;єднання %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Бездротове з&apos;єднання %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>З&apos;єднання PPPoE %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Новий VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Тип VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Експортувати</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Проксі Програма</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Особиста точка доступу</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Параметри мережі</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системний проксі-сервер</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Провідна мережа</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Дротова Мережева Карта</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Додати підключення до мережі</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Бездротова Мережева Карта</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Підключитися до прихованої мережі</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Створити PPPoE-з&apos;єднання</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>Статус VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Створити VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Імпортувати VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Конфігурація URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Ім&apos;я користувача</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Створіть точку доступу</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Інтерфейс</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>МАС</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Група</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Первинний DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Швидкість</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Вмикання режиму польоту вимикає бездротову мережу, особистку точку доступу та Bluetooth</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Некоректна адреса DNS</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не прив&apos;язано</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Пристрій MAC Addr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Адреса клонованого MAC</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Налаштувати MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Загальне</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Таке ім&apos;я вже існує</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Назва</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Обов&apos;язкове</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Автоматичне з&apos;єднання</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Додати параметри</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Створіть точку доступу</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Слід вказати</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дублювання IP-адреси</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Некоректна маска мережі</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Можна вказувати лише один шлюз</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Слід вказати</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Дублювання IP-адреси</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Можна вказувати лише один шлюз</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ігнорувати</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP-адреса</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Використовується тільки у відповідних ресурсах</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Некоректна IP-адреса</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Некоректна маска мережі</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Метод</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ігнорувати</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Параметри мережі</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Системний проксі-сервер</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Проксі програми</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим польоту</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Параметри мережі</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Мережа</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>Налаштування за допомогою Менеджера мережі</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Особиста точка доступу</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Служба</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Відмовитися від аутентифікації EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Відмовити у PAP Автентифікації</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Відмовитися від CHAP-аутентифікації</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Відмовитись від MSCHAP-аутентифікації</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Відхилити автентифікацію MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Немає стиснення даних BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Стиснення даних під час завантаження не здійснюється</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без стискання заголовків TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Немає стиснення полів протоколу</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без адреси/Стискання керування</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Надіслати луна-пакети PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Використати MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-бітне MPPE-шифрування</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE з контролем стану підключень</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Створити PPPoE з&apos;єднання</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Системний проксі-сервер</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Зберегти</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Вручну</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Необов&apos;язкове</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP-проксі</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS-проксі</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP-проксі</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS-проксі</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ігнорувати конфігурації проксі для зазначених вище вузлів і доменів</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Конфігурація URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Тунельований TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Захищений EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Зберегти пароль для цього користувача</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Зберігати паролі для усіх користувачів</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Завжди питати</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Анонімно</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Розпізнано</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Обидва</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Автоматично</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Версія 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Версія 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP-аутентифікація</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Профіль</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Анонімний ідентифікатор</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Передбачення</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC-файл</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Внутрішня аутентифікація</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP-версія</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Приватний пароль</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Некоректний пароль</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Особиста WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>Особистий WPA3</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Необхідний рівень безпеки</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Некоректний пароль</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>Особиста WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>Промислова WPA/WPA2</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>Особистий WPA3</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Спільний ключ</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Відкрита система</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Розпізнавання</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Ключ</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Прогресивний</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Налаштувати порт шлюзу</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Порт Входу</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Налаштувати інтервал перегляду</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Інтервал повторного узгодження</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Використати стиснення файлів LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Використайте зв‘язок TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Використати пристрій TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Налаштувати тонель MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Налаштувати розмір фрагменту UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Розмір фрагменту UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Обмежити Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Розмістити у випадковому порядку віддалені хости</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Прогресивний</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (типове)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Мережевий екран</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Захищений (типовий)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Слабкий</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T, коли доступно (за замовчуванням)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>Завжди NAT-T</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Вимкнено</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>Група DH 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>Група DH 2 (типово)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>Група DH 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Сервер (типова)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>Група DH 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Домен</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Постачальник</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версія</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Шифрування</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Обхідний режим NAT</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Група обробки даних IKE</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Розповсюдити конфіденційність</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Локальний порт</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Деактивувати функцію виявлення однорангових пристроїв</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Увімкнути IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Назва групи</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Ідентифікатор групи</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Спільний ключ</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Алгоритми Фази1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Алгоритми Фази2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Проксі</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Дозволити Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Сценарій CSD</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Скористайтесь FSID для вводу ключової фрази</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Сертифікати (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Сертифікати з паролем (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Статичний ключ</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Збережено</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не потрібен</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип аутентифікації</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Приватний пароль</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Налаштувати клавішу управління</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Керування клавішами</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Віддалений IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Локальний IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Усі доступні (за замовчуванням)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40 біт (менш захищене)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128 біт (найбільш захищене)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Відмовитися від аутентифікації EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Відмовити у PAP Автентифікації</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Відмовитися від CHAP-аутентифікації</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Відмовитись від MSCHAP-аутентифікації</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Відхилити автентифікацію MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Немає стиснення даних BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Стиснення даних під час завантаження не здійснюється</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Без стискання заголовків TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Немає стиснення полів протоколу</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Без адреси/Стискання керування</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Надіслати луна-пакети PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Використати MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Захист</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE з контролем стану підключень</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>Статус VPN</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Створити VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Імпортувати VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Помилка імпорту</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Помилка під час роботи з файлом</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Гаразд</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-проксі</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не потрібен</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Тип проксі</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP сервера</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>У разі збою повторювати спроби нескінченно</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>Файл CA</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Ігнорувати попередження щодо сертифікатів</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Розширення назв вузлів TLS</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>Безпека VPN</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Типовий</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Немає</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Шифр</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Збережено</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не потрібен</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Домен NT</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN-проксі</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP сервера</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Порт</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Закритий ключ</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH-агент</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Смарт-картка</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Спільний ключ</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Сертифікат CA</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Тип аутентифікації</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Сертифікат користувача</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Запит внутрішньої IP-адреси</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Забезпечити інкапсуляцію UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Використовуйте стиснення IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Увімкнути нетипові варіанти шифрування</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS Автентифікація</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Типовий</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Клієнт</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Сервер</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Збіг теми</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Тип віддаленого сертифіката</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Файл ключа</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Налаштувати клавішу управління</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Керування клавішами</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Некоректний шлюз</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Збережено</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Запитати</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Не потрібен</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Користувач</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Параметри pwd</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Пароль</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Назва групи</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Груповий пароль</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Використати гібридну автентифікацію</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Файл CA</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Спочатку підключіть мережний кабель</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Дротова Мережева Карта</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Додати підключення до мережі</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Обрати Налаштування</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Бездротова Мережева Карта</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Закрити точку доступу</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Спочатку вимкніть точку доступу, якщо ви хочете підключитися до бездротової мережі</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Підключитися до прихованої мережі</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Не прив&apos;язано</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Потрібен</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Пристрій MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Налаштувати MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Точка доступу</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Протокол</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Тип захисту</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Група</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Інтерфейс</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Маска мережі</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Шлюз</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Основний DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Префікс</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Швидкість</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Пристрій вимкнено</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>З&apos;єднано, але немає доступу до інтернету</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не з&apos;єднано</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Кабель мережі від&apos;єднано</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>З&apos;єднання</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Розпізнавання</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Отримуємо IP-адресу</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>З&apos;єднано</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Роз&apos;єднано</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Конфлікт IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Отримання адреси</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Дротова мережа</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Дротова мережа %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Бездротова мережа</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Бездротова мережа %1</translation>
    </message>
</context>
</TS>